.. neo3-python's documentation master file, created by
   sphinx-quickstart on Thu Aug  8 19:12:09 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome! This is neo-mamba's documentation
==========================================

.. toctree::
   whatsnew/index.rst
   tutorial/index.rst
   library/index.rst
   howto/index.rst
   faq/index.rst
